'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _babelTemplate = require('babel-template');

var _babelTemplate2 = _interopRequireDefault(_babelTemplate);

var _eslintTestGenerator = require('eslint-test-generator');

var _eslintTestGenerator2 = _interopRequireDefault(_eslintTestGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (babel) {
  var t = babel.types;

  return {
    visitor: {
      Program: function Program(path, state) {
        var currentBabelFile = state.file.opts.filename;

        if (!state.opts.file || currentBabelFile.indexOf(state.opts.file) > -1) {
          var opts = Object.assign({
            paths: '**/*.js',
            maxWarnings: -1
          }, state.opts);

          if (!opts.template) {
            throw new Error('You should pass in `template` to babel-plugin-eslint-test-generator\'s options.\n' + 'Possible values could be:\n' + Object.keys(_eslintTestGenerator.suites).map(function (suite) {
              return '- \'' + suite + '\'';
            }).join('\n') + '\nOr `template` could be a handlebars template string.\n\n');
          }

          // get the js source for tests
          var generatedSource = (0, _eslintTestGenerator2.default)({
            template: opts.template,
            paths: opts.paths,
            optsEslint: opts.optsEslint,
            maxWarnings: opts.maxWarnings
          });

          // get ast for tests
          var getAST = (0, _babelTemplate2.default)(generatedSource);
          var ast = getAST();

          // add in an extra line before tests are dropped in
          path.pushContainer('body', t.noop());

          // dropped in tests
          path.pushContainer('body', ast);
        }
      }
    }
  };
};